/****************************************************************************
** Meta object code from reading C++ file 'filemetadataprovider.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/baloo-widgets-17.08.3/src/filemetadataprovider.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filemetadataprovider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Baloo__FileMetaDataProvider_t {
    QByteArrayData data[9];
    char stringdata0[132];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Baloo__FileMetaDataProvider_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Baloo__FileMetaDataProvider_t qt_meta_stringdata_Baloo__FileMetaDataProvider = {
    {
QT_MOC_LITERAL(0, 0, 27), // "Baloo::FileMetaDataProvider"
QT_MOC_LITERAL(1, 28, 15), // "loadingFinished"
QT_MOC_LITERAL(2, 44, 0), // ""
QT_MOC_LITERAL(3, 45, 19), // "slotLoadingFinished"
QT_MOC_LITERAL(4, 65, 5), // "KJob*"
QT_MOC_LITERAL(5, 71, 3), // "job"
QT_MOC_LITERAL(6, 75, 21), // "slotFileFetchFinished"
QT_MOC_LITERAL(7, 97, 15), // "insertBasicData"
QT_MOC_LITERAL(8, 113, 18) // "insertEditableData"

    },
    "Baloo::FileMetaDataProvider\0loadingFinished\0"
    "\0slotLoadingFinished\0KJob*\0job\0"
    "slotFileFetchFinished\0insertBasicData\0"
    "insertEditableData"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Baloo__FileMetaDataProvider[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,   40,    2, 0x08 /* Private */,
       6,    1,   43,    2, 0x08 /* Private */,
       7,    0,   46,    2, 0x08 /* Private */,
       8,    0,   47,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void Baloo::FileMetaDataProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileMetaDataProvider *_t = static_cast<FileMetaDataProvider *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->loadingFinished(); break;
        case 1: _t->slotLoadingFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 2: _t->slotFileFetchFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 3: _t->insertBasicData(); break;
        case 4: _t->insertEditableData(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (FileMetaDataProvider::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FileMetaDataProvider::loadingFinished)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject Baloo::FileMetaDataProvider::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Baloo__FileMetaDataProvider.data,
      qt_meta_data_Baloo__FileMetaDataProvider,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Baloo::FileMetaDataProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Baloo::FileMetaDataProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Baloo__FileMetaDataProvider.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Baloo::FileMetaDataProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void Baloo::FileMetaDataProvider::loadingFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
