/****************************************************************************
** Meta object code from reading C++ file 'widgetfactory.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/baloo-widgets-17.08.3/src/widgetfactory.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'widgetfactory.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Baloo__WidgetFactory_t {
    QByteArrayData data[15];
    char stringdata0[186];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Baloo__WidgetFactory_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Baloo__WidgetFactory_t qt_meta_stringdata_Baloo__WidgetFactory = {
    {
QT_MOC_LITERAL(0, 0, 20), // "Baloo::WidgetFactory"
QT_MOC_LITERAL(1, 21, 12), // "urlActivated"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 3), // "url"
QT_MOC_LITERAL(4, 39, 17), // "dataChangeStarted"
QT_MOC_LITERAL(5, 57, 18), // "dataChangeFinished"
QT_MOC_LITERAL(6, 76, 15), // "slotTagsChanged"
QT_MOC_LITERAL(7, 92, 4), // "tags"
QT_MOC_LITERAL(8, 97, 18), // "slotCommentChanged"
QT_MOC_LITERAL(9, 116, 7), // "comment"
QT_MOC_LITERAL(10, 124, 17), // "slotRatingChanged"
QT_MOC_LITERAL(11, 142, 6), // "rating"
QT_MOC_LITERAL(12, 149, 14), // "slotTagClicked"
QT_MOC_LITERAL(13, 164, 3), // "tag"
QT_MOC_LITERAL(14, 168, 17) // "slotLinkActivated"

    },
    "Baloo::WidgetFactory\0urlActivated\0\0"
    "url\0dataChangeStarted\0dataChangeFinished\0"
    "slotTagsChanged\0tags\0slotCommentChanged\0"
    "comment\0slotRatingChanged\0rating\0"
    "slotTagClicked\0tag\0slotLinkActivated"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Baloo__WidgetFactory[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    0,   57,    2, 0x06 /* Public */,
       5,    0,   58,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   59,    2, 0x08 /* Private */,
       8,    1,   62,    2, 0x08 /* Private */,
      10,    1,   65,    2, 0x08 /* Private */,
      12,    1,   68,    2, 0x08 /* Private */,
      14,    1,   71,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QStringList,    7,
    QMetaType::Void, QMetaType::QString,    9,
    QMetaType::Void, QMetaType::UInt,   11,
    QMetaType::Void, QMetaType::QString,   13,
    QMetaType::Void, QMetaType::QString,    3,

       0        // eod
};

void Baloo::WidgetFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WidgetFactory *_t = static_cast<WidgetFactory *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->urlActivated((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 1: _t->dataChangeStarted(); break;
        case 2: _t->dataChangeFinished(); break;
        case 3: _t->slotTagsChanged((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 4: _t->slotCommentChanged((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 5: _t->slotRatingChanged((*reinterpret_cast< uint(*)>(_a[1]))); break;
        case 6: _t->slotTagClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 7: _t->slotLinkActivated((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (WidgetFactory::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WidgetFactory::urlActivated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (WidgetFactory::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WidgetFactory::dataChangeStarted)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (WidgetFactory::*_t)();
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&WidgetFactory::dataChangeFinished)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject Baloo::WidgetFactory::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_Baloo__WidgetFactory.data,
      qt_meta_data_Baloo__WidgetFactory,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Baloo::WidgetFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Baloo::WidgetFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Baloo__WidgetFactory.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Baloo::WidgetFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void Baloo::WidgetFactory::urlActivated(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Baloo::WidgetFactory::dataChangeStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Baloo::WidgetFactory::dataChangeFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
