/****************************************************************************
** Meta object code from reading C++ file 'tagwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/baloo-widgets-17.08.3/src/tagwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tagwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Baloo__TagWidget_t {
    QByteArrayData data[15];
    char stringdata0[190];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Baloo__TagWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Baloo__TagWidget_t qt_meta_stringdata_Baloo__TagWidget = {
    {
QT_MOC_LITERAL(0, 0, 16), // "Baloo::TagWidget"
QT_MOC_LITERAL(1, 17, 10), // "tagClicked"
QT_MOC_LITERAL(2, 28, 0), // ""
QT_MOC_LITERAL(3, 29, 16), // "selectionChanged"
QT_MOC_LITERAL(4, 46, 4), // "tags"
QT_MOC_LITERAL(5, 51, 15), // "setSelectedTags"
QT_MOC_LITERAL(6, 67, 12), // "setAlignment"
QT_MOC_LITERAL(7, 80, 13), // "Qt::Alignment"
QT_MOC_LITERAL(8, 94, 9), // "alignment"
QT_MOC_LITERAL(9, 104, 12), // "setReadyOnly"
QT_MOC_LITERAL(10, 117, 8), // "readOnly"
QT_MOC_LITERAL(11, 126, 11), // "slotShowAll"
QT_MOC_LITERAL(12, 138, 17), // "slotTagUpdateDone"
QT_MOC_LITERAL(13, 156, 26), // "slotKEditTagDialogFinished"
QT_MOC_LITERAL(14, 183, 6) // "result"

    },
    "Baloo::TagWidget\0tagClicked\0\0"
    "selectionChanged\0tags\0setSelectedTags\0"
    "setAlignment\0Qt::Alignment\0alignment\0"
    "setReadyOnly\0readOnly\0slotShowAll\0"
    "slotTagUpdateDone\0slotKEditTagDialogFinished\0"
    "result"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Baloo__TagWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       3,    1,   62,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   65,    2, 0x0a /* Public */,
       6,    1,   68,    2, 0x0a /* Public */,
       9,    1,   71,    2, 0x0a /* Public */,
       9,    0,   74,    2, 0x2a /* Public | MethodCloned */,
      11,    0,   75,    2, 0x08 /* Private */,
      12,    0,   76,    2, 0x08 /* Private */,
      13,    1,   77,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QStringList,    4,

 // slots: parameters
    QMetaType::Void, QMetaType::QStringList,    4,
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void, QMetaType::Bool,   10,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,   14,

       0        // eod
};

void Baloo::TagWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TagWidget *_t = static_cast<TagWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->tagClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->selectionChanged((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 2: _t->setSelectedTags((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        case 3: _t->setAlignment((*reinterpret_cast< Qt::Alignment(*)>(_a[1]))); break;
        case 4: _t->setReadyOnly((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->setReadyOnly(); break;
        case 6: _t->slotShowAll(); break;
        case 7: _t->slotTagUpdateDone(); break;
        case 8: _t->slotKEditTagDialogFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (TagWidget::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TagWidget::tagClicked)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TagWidget::*_t)(const QStringList & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&TagWidget::selectionChanged)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject Baloo::TagWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Baloo__TagWidget.data,
      qt_meta_data_Baloo__TagWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Baloo::TagWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Baloo::TagWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Baloo__TagWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Baloo::TagWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Baloo::TagWidget::tagClicked(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Baloo::TagWidget::selectionChanged(const QStringList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
