/****************************************************************************
** Meta object code from reading C++ file 'filemetadatawidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/baloo-widgets-17.08.3/src/filemetadatawidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filemetadatawidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Baloo__FileMetaDataWidget_t {
    QByteArrayData data[12];
    char stringdata0[180];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Baloo__FileMetaDataWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Baloo__FileMetaDataWidget_t qt_meta_stringdata_Baloo__FileMetaDataWidget = {
    {
QT_MOC_LITERAL(0, 0, 25), // "Baloo::FileMetaDataWidget"
QT_MOC_LITERAL(1, 26, 12), // "urlActivated"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 3), // "url"
QT_MOC_LITERAL(4, 44, 23), // "metaDataRequestFinished"
QT_MOC_LITERAL(5, 68, 13), // "KFileItemList"
QT_MOC_LITERAL(6, 82, 5), // "items"
QT_MOC_LITERAL(7, 88, 19), // "slotLoadingFinished"
QT_MOC_LITERAL(8, 108, 17), // "slotLinkActivated"
QT_MOC_LITERAL(9, 126, 21), // "slotDataChangeStarted"
QT_MOC_LITERAL(10, 148, 22), // "slotDataChangeFinished"
QT_MOC_LITERAL(11, 171, 8) // "readOnly"

    },
    "Baloo::FileMetaDataWidget\0urlActivated\0"
    "\0url\0metaDataRequestFinished\0KFileItemList\0"
    "items\0slotLoadingFinished\0slotLinkActivated\0"
    "slotDataChangeStarted\0slotDataChangeFinished\0"
    "readOnly"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Baloo__FileMetaDataWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       1,   56, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       4,    1,   47,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   50,    2, 0x08 /* Private */,
       8,    1,   51,    2, 0x08 /* Private */,
       9,    0,   54,    2, 0x08 /* Private */,
      10,    0,   55,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QUrl,    3,
    QMetaType::Void, 0x80000000 | 5,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      11, QMetaType::Bool, 0x00095103,

       0        // eod
};

void Baloo::FileMetaDataWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileMetaDataWidget *_t = static_cast<FileMetaDataWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->urlActivated((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        case 1: _t->metaDataRequestFinished((*reinterpret_cast< const KFileItemList(*)>(_a[1]))); break;
        case 2: _t->d->slotLoadingFinished(); break;
        case 3: _t->d->slotLinkActivated((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->d->slotDataChangeStarted(); break;
        case 5: _t->d->slotDataChangeFinished(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (FileMetaDataWidget::*_t)(const QUrl & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FileMetaDataWidget::urlActivated)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (FileMetaDataWidget::*_t)(const KFileItemList & );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&FileMetaDataWidget::metaDataRequestFinished)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        FileMetaDataWidget *_t = static_cast<FileMetaDataWidget *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isReadOnly(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        FileMetaDataWidget *_t = static_cast<FileMetaDataWidget *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setReadOnly(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject Baloo::FileMetaDataWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_Baloo__FileMetaDataWidget.data,
      qt_meta_data_Baloo__FileMetaDataWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *Baloo::FileMetaDataWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Baloo::FileMetaDataWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Baloo__FileMetaDataWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Baloo::FileMetaDataWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 1;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 1;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Baloo::FileMetaDataWidget::urlActivated(const QUrl & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void Baloo::FileMetaDataWidget::metaDataRequestFinished(const KFileItemList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
